@ce.
-Size of the canvas can be also overriden by specifying one of the
+Size of the canvas can be also overridden by specifying one of the
@cb{.css} .mn-width-* @ce CSS classes on the
@cb{.html}
@ce:
diff --git a/doc/platforms-windows.dox b/doc/platforms-windows.dox
index c5d5dc934..704b3ecfa 100644
--- a/doc/platforms-windows.dox
+++ b/doc/platforms-windows.dox
@@ -128,7 +128,7 @@ much as possible:
@section platform-windows-icon Executable icon
In order to supply an icon for the executable, make an `*.ico` file
-(preferrably out of multiple different sizes) and create a `*.rc` file
+(preferably out of multiple different sizes) and create a `*.rc` file
referencing it. The first argument can be anything (it can be used for
retrieving the icon later at runtime via Windows APIs), Windows always pick the
first icon in the `*.rc` file for the executable.
diff --git a/doc/snippets/CMakeLists.txt b/doc/snippets/CMakeLists.txt
index dd8510fd4..9af7aca4b 100644
--- a/doc/snippets/CMakeLists.txt
+++ b/doc/snippets/CMakeLists.txt
@@ -141,7 +141,7 @@ if(WITH_DEBUGTOOLS)
# CompareImage documentation snippet. I need it executable so I can
# copy&paste the output to the documentation. Also not using
# corrade_add_test() because it shouldn't be run as part of CTest as it
- # purposedly fails.
+ # purposely fails.
add_executable(debugtools-compareimage debugtools-compareimage.cpp)
target_link_libraries(debugtools-compareimage PRIVATE
MagnumDebugTools
diff --git a/doc/transformations.dox b/doc/transformations.dox
index b1ad714f3..7c389596d 100644
--- a/doc/transformations.dox
+++ b/doc/transformations.dox
@@ -319,7 +319,7 @@ create helper functions, if you need them.
The @ref SceneGraph API provides a hierarchical transformation hierarchy and a
correct camera-relative transformation is calculated automatically in the
-background, avoiding the need for manualy handling of model / view
+background, avoiding the need for manually handling of model / view
transformations. In particular, camera position is always specified as relative
to scene root and it gets inverted when calculating the final per-object
transformation. See @ref scenegraph for detailed description.
diff --git a/modules/FindCorrade.cmake b/modules/FindCorrade.cmake
index 9a36cce28..39e7cd4b7 100644
--- a/modules/FindCorrade.cmake
+++ b/modules/FindCorrade.cmake
@@ -100,7 +100,7 @@
# CORRADE_TARGET_MINGW - Defined if compiling under MinGW
# CORRADE_PLUGINMANAGER_NO_DYNAMIC_PLUGIN_SUPPORT - Defined if PluginManager
# doesn't support dynamic plugin loading due to platform limitations
-# CORRADE_TESTSUITE_TARGET_XCTEST - Defined if TestSuite is targetting Xcode
+# CORRADE_TESTSUITE_TARGET_XCTEST - Defined if TestSuite is targeting Xcode
# XCTest
# CORRADE_UTILITY_USE_ANSI_COLORS - Defined if ANSI escape sequences are used
# for colored output with Utility::Debug on Windows
diff --git a/modules/FindMagnum.cmake b/modules/FindMagnum.cmake
index 1c150aa05..e1fb257b2 100644
--- a/modules/FindMagnum.cmake
+++ b/modules/FindMagnum.cmake
@@ -608,7 +608,7 @@ foreach(_component ${Magnum_FIND_COMPONENTS})
# Dynamic plugins don't have any prefix (e.g. `lib` on Linux),
# search with empty prefix and then reset that back so we don't
- # accidentaly break something else
+ # accidentally break something else
set(_tmp_prefixes "${CMAKE_FIND_LIBRARY_PREFIXES}")
set(CMAKE_FIND_LIBRARY_PREFIXES "${CMAKE_FIND_LIBRARY_PREFIXES};")
diff --git a/src/Magnum/Animation/Test/PlayerTest.cpp b/src/Magnum/Animation/Test/PlayerTest.cpp
index 2d8c1eba4..10199165b 100644
--- a/src/Magnum/Animation/Test/PlayerTest.cpp
+++ b/src/Magnum/Animation/Test/PlayerTest.cpp
@@ -120,7 +120,7 @@ const struct {
initializer (not when there's just a struct and also not when
the struct is only a chrono member itself). Keeping at least one
instance here so I can monitor when this gets fixed. */
- #if !defined(CORRADE_MSVC2017_COMPATIBILITY) || defined(CORRADE_MSVC2015_COMPATIBLITY)
+ #if !defined(CORRADE_MSVC2017_COMPATIBILITY) || defined(CORRADE_MSVC2015_COMPATIBILITY)
std::chrono::hours{100*365*24},
#else
std::chrono::minutes{100*365*24*60},
diff --git a/src/Magnum/Audio/Renderer.h b/src/Magnum/Audio/Renderer.h
index a61c88114..3308019cb 100644
--- a/src/Magnum/Audio/Renderer.h
+++ b/src/Magnum/Audio/Renderer.h
@@ -50,7 +50,7 @@ class Renderer {
* @see @ref error()
*/
enum class Error: ALenum {
- NoError = AL_NO_ERROR, /**< No error occured */
+ NoError = AL_NO_ERROR, /**< No error occurred */
InvalidName = AL_INVALID_NAME, /**< Invalid name parameter */
InvalidEnum = AL_INVALID_ENUM, /**< Invalid enum parameter */
InvalidValue = AL_INVALID_VALUE, /**< Invalid enum value parameter */
diff --git a/src/Magnum/GL/AbstractShaderProgram.h b/src/Magnum/GL/AbstractShaderProgram.h
index 1af6737eb..ab23a5156 100644
--- a/src/Magnum/GL/AbstractShaderProgram.h
+++ b/src/Magnum/GL/AbstractShaderProgram.h
@@ -111,7 +111,7 @@ layout(location = 1) in vec3 normal;
layout(location = 2) in vec2 textureCoordinates;
@endcode
-Similarly for ouput attributes, you can also specify blend equation color index
+Similarly for output attributes, you can also specify blend equation color index
for them (see @ref Renderer::BlendFunction for more information about using
color input index):
diff --git a/src/Magnum/GL/Attribute.h b/src/Magnum/GL/Attribute.h
index 8a6ae43fe..1b27fc848 100644
--- a/src/Magnum/GL/Attribute.h
+++ b/src/Magnum/GL/Attribute.h
@@ -360,7 +360,7 @@ template class Attribute {
*
* Used for describing matrix attributes. Implicitly the same as size
* of given vector type (e.g. @cpp 9 @ce for a
- * @ref Magnum::Matrix3 "Matrix3"), but can be overriden for example to
+ * @ref Magnum::Matrix3 "Matrix3"), but can be overridden for example to
* ensure four-byte column alignment with 1- and 2-byte data types.
* @see @ref Vectors
*/
diff --git a/src/Magnum/GL/Buffer.h b/src/Magnum/GL/Buffer.h
index 041099796..1e9baaba4 100644
--- a/src/Magnum/GL/Buffer.h
+++ b/src/Magnum/GL/Buffer.h
@@ -477,7 +477,7 @@ class MAGNUM_GL_EXPORT Buffer: public AbstractObject {
/**
* Only one or more discrete subranges of the mapping will be
* modified. See @ref flushMappedRange() for more information. May
- * only be used in conjuction with @ref MapFlag::Write.
+ * only be used in conjunction with @ref MapFlag::Write.
*/
#ifndef MAGNUM_TARGET_GLES2
FlushExplicit = GL_MAP_FLUSH_EXPLICIT_BIT,
diff --git a/src/Magnum/GL/CMakeLists.txt b/src/Magnum/GL/CMakeLists.txt
index 935e8c524..6933702e8 100644
--- a/src/Magnum/GL/CMakeLists.txt
+++ b/src/Magnum/GL/CMakeLists.txt
@@ -176,7 +176,7 @@ add_library(MagnumGLObjects OBJECT
${MagnumGL_HEADERS}
${MagnumGL_PRIVATE_HEADERS})
# We can use both implicit include path (GLES2/gl2.h) where our headers can
-# be overriden with system ones or explicit (MagnumExternal/OpenGL/GLES2/gl2ext.h)
+# be overridden with system ones or explicit (MagnumExternal/OpenGL/GLES2/gl2ext.h)
# where only our headers will be used
target_include_directories(MagnumGLObjects PUBLIC
$)
diff --git a/src/Magnum/GL/Extensions.h b/src/Magnum/GL/Extensions.h
index 92db6ce13..321dd9b0b 100644
--- a/src/Magnum/GL/Extensions.h
+++ b/src/Magnum/GL/Extensions.h
@@ -35,7 +35,7 @@ namespace Magnum { namespace GL {
/* Standard Android build system thinks that it's okay to define unmangled
unprefixed macros. I think that whoever did that needs to be punished,
- becuase I am then not able to use that identifier for extension names.
+ because I am then not able to use that identifier for extension names.
Use CORRADE_TARGET_ANDROID here instead. */
#ifdef ANDROID
#undef ANDROID
diff --git a/src/Magnum/GL/Mesh.h b/src/Magnum/GL/Mesh.h
index ce5f329f5..7b77a0e4e 100644
--- a/src/Magnum/GL/Mesh.h
+++ b/src/Magnum/GL/Mesh.h
@@ -275,7 +275,7 @@ this:
@snippet MagnumGL.cpp Mesh-dynamic
-@section GL-Mesh-buffer-ownership Transfering buffer ownership
+@section GL-Mesh-buffer-ownership Transferring buffer ownership
If a vertex/index buffer is used only by a single mesh, it's possible to
transfer its ownership to the mesh itself to simplify resource management on
@@ -298,7 +298,7 @@ getting only a moved-out instance. For example:
Basic workflow is: bind specific framebuffer for drawing (if needed), set up
respective shader (see
@ref GL-AbstractShaderProgram-rendering-workflow "AbstractShaderProgram documentation"
-for more infromation) and call @ref AbstractShaderProgram::draw().
+for more information) and call @ref AbstractShaderProgram::draw().
@section GL-Mesh-webgl-restrictions WebGL restrictions
diff --git a/src/Magnum/GL/RenderbufferFormat.h b/src/Magnum/GL/RenderbufferFormat.h
index 0d037d79c..0a0a3182a 100644
--- a/src/Magnum/GL/RenderbufferFormat.h
+++ b/src/Magnum/GL/RenderbufferFormat.h
@@ -114,7 +114,7 @@ enum class RenderbufferFormat: GLenum {
* RGBA, each component normalized unsigned byte.
* @requires_gles30 Extension @gl_extension{ARM,rgba8} or @gl_extension{OES,rgb8_rgba8}
* in OpenGL ES 2.0.
- * @requires_webgl20 Not availabe in WebGL 1.0, use for example
+ * @requires_webgl20 Not available in WebGL 1.0, use for example
* @ref RenderbufferFormat::RGB565 or @ref RenderbufferFormat::RGBA4
* instead.
*/
diff --git a/src/Magnum/GL/Renderer.h b/src/Magnum/GL/Renderer.h
index ec7433992..8f1a71fe8 100644
--- a/src/Magnum/GL/Renderer.h
+++ b/src/Magnum/GL/Renderer.h
@@ -2114,7 +2114,7 @@ class MAGNUM_GL_EXPORT Renderer {
* WebGL.
*/
enum class GraphicsResetStatus: GLenum {
- /** No reset occured since last call. */
+ /** No reset occurred since last call. */
NoError = GL_NO_ERROR,
/**
diff --git a/src/Magnum/GL/Test/ContextTest.cpp b/src/Magnum/GL/Test/ContextTest.cpp
index afcba1fff..cbdd1c4f3 100644
--- a/src/Magnum/GL/Test/ContextTest.cpp
+++ b/src/Magnum/GL/Test/ContextTest.cpp
@@ -101,7 +101,7 @@ void ContextTest::isExtension() {
}
/* Variadic check (used in variadic Configuration::addDisabledExtensions()),
- check that it properly fails for each occurence of a non-extension */
+ check that it properly fails for each occurrence of a non-extension */
#ifndef MAGNUM_TARGET_WEBGL
CORRADE_VERIFY(Implementation::IsExtension<
Extensions::KHR::debug,
diff --git a/src/Magnum/Math/DualComplex.h b/src/Magnum/Math/DualComplex.h
index 8e32b917e..e17daa110 100644
--- a/src/Magnum/Math/DualComplex.h
+++ b/src/Magnum/Math/DualComplex.h
@@ -108,7 +108,7 @@ template class DualComplex: public Dual> {
}
/**
- * @brief Create dual complext from rotation complex and translation vector
+ * @brief Create dual complex from rotation complex and translation vector
* @m_since_latest
*
* @f[
@@ -242,7 +242,7 @@ template class DualComplex: public Dual> {
}
/**
- * @brief Multipy with dual complex number
+ * @brief Multiply with dual complex number
*
* @f[
* \hat a \hat b = a_0 b_0 + \epsilon (a_0 b_\epsilon + a_\epsilon)
diff --git a/src/Magnum/MeshTools/RemoveDuplicates.cpp b/src/Magnum/MeshTools/RemoveDuplicates.cpp
index fdb287db3..9e5fe1d84 100644
--- a/src/Magnum/MeshTools/RemoveDuplicates.cpp
+++ b/src/Magnum/MeshTools/RemoveDuplicates.cpp
@@ -73,7 +73,7 @@ std::size_t removeDuplicatesInto(const Containers::StridedArrayView2D table{
@@ -113,7 +113,7 @@ std::size_t removeDuplicatesInPlaceInto(const Containers::StridedArrayView2D table{
diff --git a/src/Magnum/MeshTools/Tipsify.cpp b/src/Magnum/MeshTools/Tipsify.cpp
index d27e87194..556de89a6 100644
--- a/src/Magnum/MeshTools/Tipsify.cpp
+++ b/src/Magnum/MeshTools/Tipsify.cpp
@@ -39,7 +39,7 @@ template void tipsifyInPlaceImplementation(const Containers::StridedArr
Containers::Array liveTriangleCount, neighborOffset, neighbors;
Implementation::buildAdjacency(indices, vertexCount, liveTriangleCount, neighborOffset, neighbors);
- /* Global time, per-vertex caching timestamps, per-triangle emmited flag */
+ /* Global time, per-vertex caching timestamps, per-triangle emitted flag */
UnsignedInt time = cacheSize+1;
Containers::Array timestamp{vertexCount};
/** @todo Have some bitset/staticbitset class for this */
diff --git a/src/Magnum/Platform/AndroidApplication.h b/src/Magnum/Platform/AndroidApplication.h
index 7790a0662..4157b2ea4 100644
--- a/src/Magnum/Platform/AndroidApplication.h
+++ b/src/Magnum/Platform/AndroidApplication.h
@@ -758,7 +758,7 @@ class AndroidApplication::MouseEvent: public InputEvent {
/**
* Left mouse button. Note that this button is not set if only
- * touch or stylus event occured.
+ * touch or stylus event occurred.
* @attention Available since Android 4.0 (API level 14), not
* detectable in earlier versions.
*/
@@ -827,7 +827,7 @@ class AndroidApplication::MouseMoveEvent: public InputEvent {
enum class Button: std::int32_t {
/**
* Left mouse button. Note that this button is not set if only
- * touch or stylus event occured.
+ * touch or stylus event occurred.
* @attention Available since Android 4.0 (API level 14), not
* detectable in earlier versions.
*/
diff --git a/src/Magnum/Platform/EmscriptenApplication.h b/src/Magnum/Platform/EmscriptenApplication.h
index 949355f56..aa95ec83a 100644
--- a/src/Magnum/Platform/EmscriptenApplication.h
+++ b/src/Magnum/Platform/EmscriptenApplication.h
@@ -234,7 +234,7 @@ for a guide covering all platform differences.
For this application in particular, @ref windowSize() can be different than
@ref framebufferSize() on HiDPI displays --- which is different from
@ref Sdl2Application behavior on Emscripten. By default, @ref dpiScaling() is
-@cpp 1.0f @ce in both dimensions but it can be overriden using custom DPI
+@cpp 1.0f @ce in both dimensions but it can be overridden using custom DPI
scaling --- the `--magnum-dpi-scaling` command-line options are supported the
same way as in @ref Sdl2Application, only in the form of URL GET parameters,
similarly to all other @ref platforms-html5-environment "command-line options".
diff --git a/src/Magnum/Platform/GlfwApplication.cpp b/src/Magnum/Platform/GlfwApplication.cpp
index 70da60d79..0f0d4574c 100644
--- a/src/Magnum/Platform/GlfwApplication.cpp
+++ b/src/Magnum/Platform/GlfwApplication.cpp
@@ -147,7 +147,7 @@ Vector2 GlfwApplication::dpiScaling(const Configuration& configuration) {
/** @todo */
#endif
- /* Use values from the configuration only if not overriden on command line
+ /* Use values from the configuration only if not overridden on command line
to something non-default. In any case explicit scaling has a precedence
before the policy. */
Implementation::GlfwDpiScalingPolicy dpiScalingPolicy{};
diff --git a/src/Magnum/Platform/GlfwApplication.h b/src/Magnum/Platform/GlfwApplication.h
index 07d7c9a93..e5941d99d 100644
--- a/src/Magnum/Platform/GlfwApplication.h
+++ b/src/Magnum/Platform/GlfwApplication.h
@@ -1124,7 +1124,7 @@ class GlfwApplication::Configuration {
* @brief DPI scaling policy
*
* DPI scaling policy when requesting a particular window size. Can
- * be overriden on command-line using `--magnum-dpi-scaling` or via
+ * be overridden on command-line using `--magnum-dpi-scaling` or via
* the `MAGNUM_DPI_SCALING` environment variable.
* @see @ref setSize(), @ref Platform-Sdl2Application-dpi
*/
diff --git a/src/Magnum/Platform/Sdl2Application.cpp b/src/Magnum/Platform/Sdl2Application.cpp
index 8a536e9e7..4effb5ee8 100644
--- a/src/Magnum/Platform/Sdl2Application.cpp
+++ b/src/Magnum/Platform/Sdl2Application.cpp
@@ -207,7 +207,7 @@ Vector2 Sdl2Application::dpiScaling(const Configuration& configuration) {
/* Handled below, warning printed only when using virtual DPI scaling */
#endif
- /* Use values from the configuration only if not overriden on command line
+ /* Use values from the configuration only if not overridden on command line
to something non-default. In any case explicit scaling has a precedence
before the policy. */
Implementation::Sdl2DpiScalingPolicy dpiScalingPolicy{};
@@ -887,7 +887,7 @@ bool Sdl2Application::mainLoopIteration() {
switch(event.type) {
case SDL_WINDOWEVENT:
switch(event.window.event) {
- /* Not using SDL_WINDOWEVENT_RESIZED, because that doens't
+ /* Not using SDL_WINDOWEVENT_RESIZED, because that doesn't
get fired when the window is resized programmatically
(such as through setMaxWindowSize()) */
case SDL_WINDOWEVENT_SIZE_CHANGED: {
diff --git a/src/Magnum/Primitives/Test/GradientTest.cpp b/src/Magnum/Primitives/Test/GradientTest.cpp
index 1df2e159e..bb0f852e1 100644
--- a/src/Magnum/Primitives/Test/GradientTest.cpp
+++ b/src/Magnum/Primitives/Test/GradientTest.cpp
@@ -60,7 +60,7 @@ GradientTest::GradientTest() {
using namespace Magnum::Math::Literals;
void GradientTest::gradient2D() {
- /* The corners sould have 0.2, 0.4, 0.6, 0.8 blends */
+ /* The corners should have 0.2, 0.4, 0.6, 0.8 blends */
Trade::MeshData gradient = Primitives::gradient2D(
{-1.0f, 2.0f}, {0.2f, 0.6f, 1.0f},
{1.0f, -2.0f}, {0.4f, 1.0f, 0.0f});
@@ -115,7 +115,7 @@ void GradientTest::gradient2DVertical() {
}
void GradientTest::gradient3D() {
- /* The corners sould have 0.2, 0.4, 0.6, 0.8 blends */
+ /* The corners should have 0.2, 0.4, 0.6, 0.8 blends */
Trade::MeshData gradient = Primitives::gradient3D(
{-1.0f, 2.0f, -1.5f}, {0.2f, 0.6f, 1.0f},
{1.0f, -2.0f, -1.5f}, {0.4f, 1.0f, 0.0f});
diff --git a/src/Magnum/SceneGraph/Test/AnimableTest.cpp b/src/Magnum/SceneGraph/Test/AnimableTest.cpp
index 36306c1c4..e2bff1025 100644
--- a/src/Magnum/SceneGraph/Test/AnimableTest.cpp
+++ b/src/Magnum/SceneGraph/Test/AnimableTest.cpp
@@ -370,7 +370,7 @@ template void AnimableTest::pause() {
CORRADE_COMPARE(animable.time, 1.5f);
/* Unpausing, next step should continue from absolute time when pause
- occured */
+ occurred */
animable.setState(AnimationState::Running);
group.step(5.0f, 0.5f);
CORRADE_COMPARE(animable.state(), AnimationState::Running);
diff --git a/src/Magnum/Shaders/FlatGL.h b/src/Magnum/Shaders/FlatGL.h
index ffca52dac..d0bcc08fb 100644
--- a/src/Magnum/Shaders/FlatGL.h
+++ b/src/Magnum/Shaders/FlatGL.h
@@ -85,7 +85,7 @@ Common rendering setup:
If you want to use a texture, you need to provide also the
@ref TextureCoordinates attribute. Pass @ref Flag::Textured to the constructor
and then at render time don't forget to bind also the texture via
-@ref bindTexture(). The texture is multipled by the color, which is by default
+@ref bindTexture(). The texture is multiplied by the color, which is by default
set to @cpp 0xffffffff_rgbaf @ce. Common mesh setup:
@snippet MagnumShaders-gl.cpp FlatGL-usage-textured1
diff --git a/src/Magnum/Shaders/MeshVisualizerGL.h b/src/Magnum/Shaders/MeshVisualizerGL.h
index 878418692..ca7197f55 100644
--- a/src/Magnum/Shaders/MeshVisualizerGL.h
+++ b/src/Magnum/Shaders/MeshVisualizerGL.h
@@ -669,7 +669,7 @@ this, the mesh will be rendered in a single color.
If you don't have geometry shaders, you need to enable @ref Flag::NoGeometryShader
(done by default in OpenGL ES 2.0) and use only **non-indexed** triangle meshes
-(see @ref MeshTools::duplicate() for a possible solution). Additionaly, if you
+(see @ref MeshTools::duplicate() for a possible solution). Additionally, if you
have OpenGL < 3.1 or OpenGL ES 2.0, you need to provide also the
@ref VertexIndex attribute.
diff --git a/src/Magnum/Shaders/PhongGL.h b/src/Magnum/Shaders/PhongGL.h
index 5c1f014fe..37a06aa0f 100644
--- a/src/Magnum/Shaders/PhongGL.h
+++ b/src/Magnum/Shaders/PhongGL.h
@@ -66,7 +66,7 @@ If you want to use textures, you need to provide also the
the constructor and then at render time don't forget to also call appropriate
subset of @ref bindAmbientTexture(), @ref bindDiffuseTexture() and
@ref bindSpecularTexture() (or the combined @ref bindTextures()). The texture
-is multipled by the color, which is by default set to fully opaque white for
+is multiplied by the color, which is by default set to fully opaque white for
enabled textures. Mesh setup with a diffuse and a specular texture:
@snippet MagnumShaders-gl.cpp PhongGL-usage-texture1
diff --git a/src/Magnum/Shaders/Test/PhongGLTest.cpp b/src/Magnum/Shaders/Test/PhongGLTest.cpp
index 4a1c18461..c70e5d332 100644
--- a/src/Magnum/Shaders/Test/PhongGLTest.cpp
+++ b/src/Magnum/Shaders/Test/PhongGLTest.cpp
@@ -655,7 +655,7 @@ const struct {
{"point, range=0.0", "light-none.tga",
{0.75f, -0.75f, -0.75f, 1.0f}, Color3{1.0f}, Color3{1.0f},
1.0f, 0.0f, {}},
- /* Distance is 0, which means the direction is always prependicular and
+ /* Distance is 0, which means the direction is always perpendicular and
thus contributes nothing */
{"point, distance=0", "light-none.tga",
{0.75f, -0.75f, -0.75f, 1.0f}, Color3{1.0f}, Color3{1.0f},
diff --git a/src/Magnum/Text/Renderer.cpp b/src/Magnum/Text/Renderer.cpp
index e6dfd0762..c0b059f9c 100644
--- a/src/Magnum/Text/Renderer.cpp
+++ b/src/Magnum/Text/Renderer.cpp
@@ -72,7 +72,7 @@ std::tuple, Range2D> renderVerticesInternal(AbstractFont& fo
std::vector vertices;
vertices.reserve(text.size()*4);
- /* Total rendered bounds, intial line position, line increment, last+1
+ /* Total rendered bounds, initial line position, line increment, last+1
vertex on previous line */
Range2D rectangle;
Vector2 linePosition;
diff --git a/src/Magnum/Trade/AbstractImporter.h b/src/Magnum/Trade/AbstractImporter.h
index 720c40b3e..310143e79 100644
--- a/src/Magnum/Trade/AbstractImporter.h
+++ b/src/Magnum/Trade/AbstractImporter.h
@@ -283,7 +283,7 @@ properly use the callbacks to both load the top-level file in @ref doOpenFile()
and also load any external files when needed. The @ref doOpenFile() can
delegate back into the base implementation, but it should remember at least the
base file path to pass correct paths to subsequent file callbacks. The
-@ref doSetFileCallback() can be overriden in case it's desired to respond to
+@ref doSetFileCallback() can be overridden in case it's desired to respond to
file loading callback setup, but doesn't have to be.
For multi-data formats the file opening shouldn't take long and all parsing
@@ -1526,7 +1526,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doScene() (with correct scene count
+ * preferably during @ref doScene() (with correct scene count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doSceneCount() const;
@@ -1553,7 +1553,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doAnimation() (with correct animation count
+ * preferably during @ref doAnimation() (with correct animation count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doAnimationCount() const;
@@ -1580,7 +1580,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doLight() (with correct light count
+ * preferably during @ref doLight() (with correct light count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doLightCount() const;
@@ -1607,7 +1607,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doCamera() (with correct camera count
+ * preferably during @ref doCamera() (with correct camera count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doCameraCount() const;
@@ -1634,7 +1634,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doObject2D() (with correct object count
+ * preferably during @ref doObject2D() (with correct object count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doObject2DCount() const;
@@ -1661,7 +1661,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doObject3D() (with correct object count
+ * preferably during @ref doObject3D() (with correct object count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doObject3DCount() const;
@@ -1689,7 +1689,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doSkin2D() (with correct skin count
+ * preferably during @ref doSkin2D() (with correct skin count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doSkin2DCount() const;
@@ -1722,7 +1722,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doSkin3D() (with correct skin count
+ * preferably during @ref doSkin3D() (with correct skin count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doSkin3DCount() const;
@@ -1755,7 +1755,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doMesh() (with correct mesh count
+ * preferably during @ref doMesh() (with correct mesh count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doMeshCount() const;
@@ -1931,7 +1931,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doMaterial() (with correct material count
+ * preferably during @ref doMaterial() (with correct material count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doMaterialCount() const;
@@ -1958,7 +1958,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doTexture() (with correct texture count
+ * preferably during @ref doTexture() (with correct texture count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doTextureCount() const;
@@ -1985,7 +1985,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doImage1D() (with correct image count
+ * preferably during @ref doImage1D() (with correct image count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doImage1DCount() const;
@@ -2021,7 +2021,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doImage2D() (with correct image count
+ * preferably during @ref doImage2D() (with correct image count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doImage2DCount() const;
@@ -2065,7 +2065,7 @@ class MAGNUM_TRADE_EXPORT AbstractImporter: public PluginManager::AbstractManagi
*
* Default implementation returns @cpp 0 @ce. This function isn't
* expected to fail --- if an import error occus, it should be handled
- * preferrably during @ref doImage3D() (with correct image count
+ * preferably during @ref doImage3D() (with correct image count
* reported), and if not possible, already during file opening.
*/
virtual UnsignedInt doImage3DCount() const;
diff --git a/src/Magnum/Trade/MeshData.h b/src/Magnum/Trade/MeshData.h
index a83083fb9..6b84034ae 100644
--- a/src/Magnum/Trade/MeshData.h
+++ b/src/Magnum/Trade/MeshData.h
@@ -447,7 +447,7 @@ class MAGNUM_TRADE_EXPORT MeshAttributeData {
* used in most @ref MeshTools algorithms.
*
* Additionally, for even more flexibility, the @p vertexCount can be
- * overriden at @ref MeshData construction time, however all attributes
+ * overridden at @ref MeshData construction time, however all attributes
* are still required to have the same vertex count to catch accidents.
*
* Note that due to the @cpp constexpr @ce nature of this constructor,
diff --git a/src/Magnum/Trade/PbrClearCoatMaterialData.h b/src/Magnum/Trade/PbrClearCoatMaterialData.h
index b8e2039f5..77f71a168 100644
--- a/src/Magnum/Trade/PbrClearCoatMaterialData.h
+++ b/src/Magnum/Trade/PbrClearCoatMaterialData.h
@@ -72,7 +72,7 @@ class MAGNUM_TRADE_EXPORT PbrClearCoatMaterialData: public MaterialLayerData::value);
/* Variadic check (used in variadic addEnabledExtensions()), check that it
- properly fails for each occurence of a device extension */
+ properly fails for each occurrence of a device extension */
CORRADE_VERIFY(Implementation::IsInstanceExtension<
Extensions::KHR::get_physical_device_properties2,
Extensions::KHR::external_memory_capabilities,
@@ -103,7 +103,7 @@ void ExtensionsTest::isExtension() {
}
/* Variadic check (used in variadic addEnabledExtensions()), check that it
- properly fails for each occurence of a device extension */
+ properly fails for each occurrence of a device extension */
CORRADE_VERIFY(Implementation::IsExtension<
Extensions::KHR::external_memory,
Extensions::KHR::depth_stencil_resolve,
diff --git a/src/Magnum/Vk/Test/MeshVkTest.cpp b/src/Magnum/Vk/Test/MeshVkTest.cpp
index 529cb6abd..8bde055c1 100644
--- a/src/Magnum/Vk/Test/MeshVkTest.cpp
+++ b/src/Magnum/Vk/Test/MeshVkTest.cpp
@@ -319,7 +319,7 @@ void MeshVkTest::cmdDrawIndexed() {
{
Buffer buffer{device(), BufferCreateInfo{
BufferUsage::VertexBuffer|BufferUsage::IndexBuffer,
- /* Artifical offset at the beginning to test that the offset is
+ /* Artificial offset at the beginning to test that the offset is
used correctly in both cases */
32 + 12*4 + sizeof(QuadIndexData)
}, MemoryFlag::HostVisible};
diff --git a/src/Magnum/Platform/EmscriptenApplication.cpp b/src/Magnum/Platform/EmscriptenApplication.cpp
index 5e3e018ce..500829dc8 100644
--- a/src/Magnum/Platform/EmscriptenApplication.cpp
+++ b/src/Magnum/Platform/EmscriptenApplication.cpp
@@ -284,7 +284,7 @@ void EmscriptenApplication::create(const Configuration& configuration, const GLC
Vector2 EmscriptenApplication::dpiScaling(const Configuration& configuration) const {
std::ostream* verbose = _verboseLog ? Debug::output() : nullptr;
/* Use values from the configuration only if not overriden on command line.
In any case explicit scaling has a precedence before the policy. */
if(!_commandLineDpiScaling.isZero()) {
Debug{verbose} << "Platform::EmscriptenApplication: user-defined DPI scaling" << _commandLineDpiScaling;
@@ -824,7 +824,7 @@ void EmscriptenApplication::redraw() {
is possible), and no amount of \\\\$$$ helps avoiding that
xylophone); but doing so means we forever hardcode what
functions are exported and thus whatever extra Emscripten needs
- to export will be overriden by this, causing only pain and
+ to export will be overridden by this, causing only pain and
misery.
So instead we rely on the implementation details of dynCall,
@@ -284,7 +284,7 @@ void EmscriptenApplication::create(const Configuration& configuration, const GLC
Vector2 EmscriptenApplication::dpiScaling(const Configuration& configuration) const {
std::ostream* verbose = _verboseLog ? Debug::output() : nullptr;
- /* Use values from the configuration only if not overriden on command line.
+ /* Use values from the configuration only if not overridden on command line.
In any case explicit scaling has a precedence before the policy. */
if(!_commandLineDpiScaling.isZero()) {
diff --git a/src/Magnum/Platform/Sdl2Application.h b/src/Magnum/Platform/Sdl2Application.h
index f0561bbdd..b4fdbe514 100644
--- a/src/Magnum/Platform/Sdl2Application.h
+++ b/src/Magnum/Platform/Sdl2Application.h
@@ -419,25 +419,25 @@ The default is depending on the platform:
@ref windowSize() and @ref framebufferSize() will differ depending on
whether `NSHighResolutionCapable` is enabled in the `*.plist` file or not.
By default, @ref dpiScaling() is @cpp 1.0f @ce in both dimensions but it
- can be overriden using custom DPI scaling.
+ can be overridden using custom DPI scaling.
- On Windows, the default is @ref Configuration::DpiScalingPolicy::Framebuffer.
The @ref windowSize() and @ref framebufferSize() is always the same.
Depending on whether the DPI awareness was enabled in the manifest file or
set by the `SetProcessDpiAwareness()` API, @ref dpiScaling() is either
@cpp 1.0f @ce in both dimensions, indicating a low-DPI screen or a
non-DPI-aware app, or some other value for HiDPI screens. In both cases the
- value can be overriden using custom DPI scaling.
+ value can be overridden using custom DPI scaling.
- On Linux, the default is @ref Configuration::DpiScalingPolicy::Virtual,
taken from the `Xft.dpi` property. If the property is not available, it
falls back to @ref Configuration::DpiScalingPolicy::Physical, querying the
monitor DPI value. The @ref windowSize() and @ref framebufferSize() is
always the same, @ref dpiScaling() contains the queried DPI scaling value.
- The value can be overriden using custom DPI scaling.
+ The value can be overridden using custom DPI scaling.
- On @ref CORRADE_TARGET_EMSCRIPTEN "Emscripten", the default is physical DPI
scaling, taken from [Window.getDevicePixelRatio()](https://developer.mozilla.org/en-US/docs/Web/API/Window/devicePixelRatio). The
@ref windowSize() and @ref framebufferSize() is always the same,
@ref dpiScaling() contains the queried DPI scaling value. The value can be
- overriden using custom DPI scaling. Note that this is different from the
+ overridden using custom DPI scaling. Note that this is different from the
behavior in @ref EmscriptenApplication --- Emscripten's SDL implementation
has some additional emulation code that reports event coordinates in
framebuffer pixels instead of CSS pixels. See
@@ -1755,7 +1755,7 @@ class Sdl2Application::Configuration {
* @brief DPI scaling policy
*
* DPI scaling policy when requesting a particular window size. Can
* be overriden on command-line using `--magnum-dpi-scaling` or via
* the `MAGNUM_DPI_SCALING` environment variable.
* @see @ref setSize(), @ref Platform-Sdl2Application-dpi
*/
@@ -1755,7 +1755,7 @@ class Sdl2Application::Configuration {
*
* DPI scaling policy when requesting a particular window size. Can
- * be overriden on command-line using `--magnum-dpi-scaling` or via
+ * be overridden on command-line using `--magnum-dpi-scaling` or via
* the `MAGNUM_DPI_SCALING` environment variable.
* @see @ref setSize(), @ref Platform-Sdl2Application-dpi
diff --git a/src/Magnum/SceneGraph/Object.hpp b/src/Magnum/SceneGraph/Object.hpp
index 4e44e795d..6267c5558 100644
--- a/src/Magnum/SceneGraph/Object.hpp
+++ b/src/Magnum/SceneGraph/Object.hpp
@@ -211,7 +211,7 @@ template std::vector Ob
/* Mark all original objects as joints and create initial list of joints
from them */
for(std::size_t i = 0; i != objects.size(); ++i) {
/* Multiple occurences of one object in the array, don't overwrite it
with different counter */
if(objects[i].get().counter != 0xFFFFu) continue;
@@ -231,7 +231,7 @@ template std::vector Ob
/* Mark all objects up the hierarchy as visited */
auto it = objects.begin();
while(!objects.empty()) {
- /* Already visited, remove and continue to next (duplicate occurence) */
+ /* Already visited, remove and continue to next (duplicate occurrence) */
if(it->get().flags & Flag::Visited) {
it = objects.erase(it);
continue;
@@ -276,7 +276,7 @@ template std::vector Ob
for(std::size_t i = 0; i != jointTransformations.size(); ++i)
computeJointTransformation(jointObjects, jointTransformations, i, finalTransformation);
/* Copy transformation for second or next occurences from first occurence
of duplicate object */
for(std::size_t i = 0; i != objectCount; ++i) {
if(jointObjects[i].get().counter != i)
@@ -285,7 +285,7 @@ template std::vector Ob
/* All visited marks are now cleaned, clean joint marks and counters */
for(auto i: jointObjects) {
/* All not-already cleaned objects (...duplicate occurences) should
have joint mark */
CORRADE_INTERNAL_ASSERT(i.get().counter == 0xFFFFu || i.get().flags & Flag::Joint);
i.get().flags &= ~Flag::Joint;
@@ -301,7 +301,7 @@ template typename Transformation::DataType Object> o = jointObjects[joint];
/* Transformation already computed ("unvisited" by this function before
- either due to recursion or duplicate object occurences), done */
+ either due to recursion or duplicate object occurrences), done */
if(!(o.get().flags & Flag::Visited)) return jointTransformations[joint];
/* Initialize transformation */
@@ -211,7 +211,7 @@ template std::vector Ob
from them */
for(std::size_t i = 0; i != objects.size(); ++i) {
- /* Multiple occurences of one object in the array, don't overwrite it
+ /* Multiple occurrences of one object in the array, don't overwrite it
with different counter */
if(objects[i].get().counter != 0xFFFFu) continue;
@@ -276,7 +276,7 @@ template std::vector Ob
for(std::size_t i = 0; i != jointTransformations.size(); ++i)
computeJointTransformation(jointObjects, jointTransformations, i, finalTransformation);
- /* Copy transformation for second or next occurences from first occurence
+ /* Copy transformation for second or next occurrences from first occurrence
of duplicate object */
for(std::size_t i = 0; i != objectCount; ++i) {
@@ -285,7 +285,7 @@ template std::vector Ob
/* All visited marks are now cleaned, clean joint marks and counters */
for(auto i: jointObjects) {
- /* All not-already cleaned objects (...duplicate occurences) should
+ /* All not-already cleaned objects (...duplicate occurrences) should
have joint mark */
CORRADE_INTERNAL_ASSERT(i.get().counter == 0xFFFFu || i.get().flags & Flag::Joint);